'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _chai = require('chai');

var _sinon = require('sinon');

var _sinon2 = _interopRequireDefault(_sinon);

var _enzyme = require('enzyme');

var _PageButton = require('./PageButton');

var _PageButton2 = _interopRequireDefault(_PageButton);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<PageButton>', function () {
  var wrapper = void 0;
  var onPageChangeCallback = _sinon2.default.stub();
  var props = {
    onPageChange: onPageChangeCallback,
    page: 2
  };

  describe('default PageButton', function () {
    beforeEach(function () {
      wrapper = (0, _enzyme.shallow)(_react2.default.createElement(_PageButton2.default, _extends({}, props, { active: true })));
    });

    it('should render a PageButton correctly', function () {
      (0, _chai.expect)(wrapper.find('button.page-link').length).to.equal(1);
      (0, _chai.expect)(wrapper.text()).to.equal('' + props.page);
      (0, _chai.expect)(wrapper.prop('title')).to.equal('');
    });

    describe('when clicking', function () {
      var preventDefault = void 0;
      beforeEach(function () {
        preventDefault = _sinon2.default.stub();
        wrapper.find('button.page-link').simulate('click', { preventDefault: preventDefault });
      });

      afterEach(function () {
        onPageChangeCallback.reset();
      });

      it('should call e.preventDefault', function () {
        (0, _chai.expect)(preventDefault.calledOnce).to.equal(true);
      });

      it('should call onPageChange prop', function () {
        (0, _chai.expect)(onPageChangeCallback.calledOnce).to.equal(true);
      });

      it('should call onPageChange prop with the correct argument', function () {
        (0, _chai.expect)(onPageChangeCallback.calledWith(props.page)).to.equal(true);
      });
    });
  });

  describe('when active prop is true', function () {
    beforeEach(function () {
      wrapper = (0, _enzyme.shallow)(_react2.default.createElement(_PageButton2.default, _extends({}, props, { active: true })));
    });

    it('should render PageButton correctly', function () {
      (0, _chai.expect)(wrapper.length).to.equal(1);
      (0, _chai.expect)(wrapper.hasClass('active')).to.equal(true);
    });
  });

  describe('when active prop is false', function () {
    beforeEach(function () {
      wrapper = (0, _enzyme.shallow)(_react2.default.createElement(_PageButton2.default, _extends({}, props, { active: false })));
    });

    it('should render PageButton correctly', function () {
      (0, _chai.expect)(wrapper.length).to.equal(1);
      (0, _chai.expect)(wrapper.hasClass('active')).to.equal(false);
    });
  });

  describe('when title prop is defined', function () {
    var title = 'aTitle';
    beforeEach(function () {
      wrapper = (0, _enzyme.shallow)(_react2.default.createElement(_PageButton2.default, _extends({}, props, { active: true, title: title })));
    });

    it('should render PageButton correctly', function () {
      (0, _chai.expect)(wrapper.length).to.equal(1);
      (0, _chai.expect)(wrapper.prop('title')).to.equal(title);
    });
  });
});