'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _pageResolver = require('../src/page-resolver');

var _pageResolver2 = _interopRequireDefault(_pageResolver);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var extendTo = function extendTo(Base) {
  return function (_Base) {
    _inherits(MockComponent, _Base);

    function MockComponent(props) {
      _classCallCheck(this, MockComponent);

      var _this = _possibleConstructorReturn(this, (MockComponent.__proto__ || Object.getPrototypeOf(MockComponent)).call(this, props));

      _this.state = _this.initialState();
      return _this;
    }

    _createClass(MockComponent, [{
      key: 'render',
      value: function render() {
        return null;
      }
    }]);

    return MockComponent;
  }(Base);
};

describe('PageResolver', function () {
  var ExtendBase = (0, _pageResolver2.default)(_react.Component);
  var MockComponent = extendTo(ExtendBase);

  var createMockProps = function createMockProps() {
    return {
      dataSize: 100,
      sizePerPageList: [10, 20, 30, 50],
      currPage: 1,
      currSizePerPage: 10,
      pageStartIndex: 1,
      paginationSize: 5,
      withFirstAndLast: true,
      firstPageText: '<<',
      prePageText: '<',
      nextPageText: '>',
      lastPageText: '>>',
      alwaysShowAllBtns: false
    };
  };

  var wrapper = void 0;

  describe('initialize', function () {
    beforeEach(function () {
      var mockElement = _react2.default.createElement(MockComponent, createMockProps(), null);
      wrapper = (0, _enzyme.shallow)(mockElement);
    });

    it('should creating initial state correctly', function () {
      var instance = wrapper.instance();
      expect(instance.state.totalPages).toBeDefined();
      expect(instance.state.totalPages).toEqual(instance.calculateTotalPage());
      expect(instance.state.lastPage).toBeDefined();
      expect(instance.state.lastPage).toEqual(instance.calculateLastPage(instance.state.totalPages));
      expect(instance.state.dropdownOpen).toBeDefined();
      expect(instance.state.dropdownOpen).toBeFalsy();
    });
  });

  describe('backToPrevPage', function () {
    var props = createMockProps();

    describe('when props.currPage is not hitting props.pageStartIndex', function () {
      beforeEach(function () {
        props.currPage = 2;
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting previous page correctly', function () {
        var instance = wrapper.instance();
        expect(instance.backToPrevPage()).toEqual(props.currPage - 1);
      });
    });

    describe('when props.currPage is hitting props.pageStartIndex', function () {
      beforeEach(function () {
        props.currPage = props.pageStartIndex;
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should always getting page which must eq props.pageStartIndex', function () {
        var instance = wrapper.instance();
        expect(instance.backToPrevPage()).toEqual(props.pageStartIndex);
      });
    });
  });

  describe('goToNextPage', function () {
    var props = createMockProps();

    describe('when props.currPage is not hitting state.lastPage', function () {
      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting previous page correctly', function () {
        var instance = wrapper.instance();
        expect(instance.goToNextPage()).toEqual(props.currPage + 1);
      });
    });

    describe('when props.currPage is hitting state.lastpage', function () {
      beforeEach(function () {
        props.currPage = 10;
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should always getting page which must eq props.pageStartIndex', function () {
        var instance = wrapper.instance();
        expect(instance.goToNextPage()).toEqual(instance.state.lastPage);
      });
    });
  });

  describe('calculateFromTo', function () {
    var props = createMockProps();
    beforeEach(function () {
      var mockElement = _react2.default.createElement(MockComponent, props, null);
      wrapper = (0, _enzyme.shallow)(mockElement);
    });

    it('should return correct array with from and to value', function () {
      var instance = wrapper.instance();
      expect(instance.calculateFromTo()).toEqual([1, props.currSizePerPage]);
    });

    describe('if data is empty', function () {
      beforeEach(function () {
        props.dataSize = 87;
        props.currPage = 9;
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should return correct array with from and to value', function () {
        var instance = wrapper.instance();
        expect(instance.calculateFromTo()).toEqual([81, props.dataSize]);
      });
    });

    describe('if current page is last page', function () {
      beforeEach(function () {
        props.dataSize = 0;
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should return correct array with from and to value', function () {
        var instance = wrapper.instance();
        expect(instance.calculateFromTo()).toEqual([0, 0]);
      });
    });
  });

  describe('calculateTotalPage', function () {
    var props = createMockProps();

    describe('when missing sizePerPage argument', function () {
      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting total pages correctly by default props.currSizePerPage', function () {
        var instance = wrapper.instance();
        expect(instance.calculateTotalPage()).toEqual(10);
      });
    });

    describe('when sizePerPage argument given', function () {
      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting total pages correctly by sizePerPage argument', function () {
        var instance = wrapper.instance();
        expect(instance.calculateTotalPage(25)).toEqual(4);
      });
    });
  });

  describe('calculateLastPage', function () {
    beforeEach(function () {
      var props = createMockProps();
      var mockElement = _react2.default.createElement(MockComponent, props, null);
      wrapper = (0, _enzyme.shallow)(mockElement);
    });

    it('should getting last page correctly', function () {
      var instance = wrapper.instance();
      expect(instance.calculateLastPage(instance.state.totalPages)).toEqual(10);
    });
  });

  describe('calculatePages', function () {
    describe('calculate by state.totalPages and state.lastPage', function () {
      var props = createMockProps();
      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting pages list correctly', function () {
        var instance = wrapper.instance();
        expect(instance.calculatePages()).toEqual([props.prePageText, 1, 2, 3, 4, 5, props.nextPageText, props.lastPageText]);

        expect(instance.calculatePages(4, 4)).toEqual([props.prePageText, 1, 2, 3, 4, props.nextPageText]);
      });
    });

    describe('calculate by props.currPage', function () {
      var props = createMockProps();
      var firstPageText = props.firstPageText,
          prePageText = props.prePageText,
          nextPageText = props.nextPageText,
          lastPageText = props.lastPageText;


      it('should getting pages list correctly', function () {
        var currPages = Array.from(Array(10).keys());
        currPages.forEach(function (currPage) {
          props.currPage = currPage + 1;
          wrapper = (0, _enzyme.shallow)(_react2.default.createElement(MockComponent, props));
          var pageList = wrapper.instance().calculatePages();

          if (props.currPage < 4) {
            expect(pageList).toEqual([prePageText, 1, 2, 3, 4, 5, nextPageText, lastPageText]);
          } else if (props.currPage > 7) {
            expect(pageList).toEqual([firstPageText, prePageText, 6, 7, 8, 9, 10, nextPageText]);
          } else if (props.currPage === 4) {
            expect(pageList).toEqual([firstPageText, prePageText, 2, 3, 4, 5, 6, nextPageText, lastPageText]);
          } else if (props.currPage === 5) {
            expect(pageList).toEqual([firstPageText, prePageText, 3, 4, 5, 6, 7, nextPageText, lastPageText]);
          } else if (props.currPage === 6) {
            expect(pageList).toEqual([firstPageText, prePageText, 4, 5, 6, 7, 8, nextPageText, lastPageText]);
          } else {
            expect(pageList).toEqual([firstPageText, prePageText, 5, 6, 7, 8, 9, nextPageText, lastPageText]);
          }
        });
      });
    });

    describe('the quantity of pages is calculated by props.paginationSize', function () {
      var props = createMockProps();
      var indicators = [props.firstPageText, props.prePageText, props.lastPageText, props.nextPageText];

      it('should getting pages list correctly', function () {
        [1, 3, 5, 8, 10].forEach(function (paginationSize) {
          props.paginationSize = paginationSize;
          wrapper = (0, _enzyme.shallow)(_react2.default.createElement(MockComponent, props));
          var pageList = wrapper.instance().calculatePages();
          var result = pageList.filter(function (p) {
            return indicators.indexOf(p) === -1;
          });
          expect(result.length).toEqual(props.paginationSize);
        });
      });
    });

    describe('when props.withFirstAndLast is true', function () {
      var props = createMockProps();
      describe('and last page is not visible by props.currPage', function () {
        it('should getting pages list which contain last page indication', function () {
          [1, 2, 3, 4, 5, 6, 7].forEach(function (currPage) {
            props.currPage = currPage;
            wrapper = (0, _enzyme.shallow)(_react2.default.createElement(MockComponent, props));
            var pageList = wrapper.instance().calculatePages();
            expect(pageList.indexOf(props.lastPageText) > -1).toBeTruthy();
          });
        });
      });

      describe('and first page is not visible by props.currPage', function () {
        it('should getting pages list which contain first page indication', function () {
          [10, 9, 8, 7, 6, 5, 4].forEach(function (currPage) {
            props.currPage = currPage;
            wrapper = (0, _enzyme.shallow)(_react2.default.createElement(MockComponent, props));
            var pageList = wrapper.instance().calculatePages();
            expect(pageList.indexOf(props.firstPageText) > -1).toBeTruthy();
          });
        });
      });
    });

    describe('when props.withFirstAndLast is false', function () {
      var props = createMockProps();
      it('should not contain first and last page indication always', function () {
        var currPages = Array.from(Array(10).keys());
        currPages.forEach(function (currPage) {
          props.currPage = currPage + 1;
          props.withFirstAndLast = false;
          wrapper = (0, _enzyme.shallow)(_react2.default.createElement(MockComponent, props));
          var pageList = wrapper.instance().calculatePages();
          expect(pageList.indexOf(props.lastPageText) > -1).toBeFalsy();
          expect(pageList.indexOf(props.firstPageText) > -1).toBeFalsy();
        });
      });
    });

    describe('when props.pageStartIndex is negative number', function () {
      var props = createMockProps();
      props.pageStartIndex = -2;
      props.currPage = -2;

      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting last page correctly', function () {
        var pageList = wrapper.instance().calculatePages();
        expect(pageList).toEqual([props.prePageText, -2, -1, 0, 1, 2, props.nextPageText, props.lastPageText]);
      });
    });

    describe('when props.alwaysShowAllBtns is true', function () {
      var props = createMockProps();
      props.alwaysShowAllBtns = true;
      props.currPage = 1;
      props.dataSize = 11;

      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should always having next and previous page indication', function () {
        var pageList = wrapper.instance().calculatePages();
        expect(pageList.indexOf(props.nextPageText) > -1).toBeTruthy();
        expect(pageList.indexOf(props.prePageText) > -1).toBeTruthy();
      });
    });

    describe('when state.totalPages is zero', function () {
      var props = createMockProps();
      props.dataSize = 0;

      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting empty array', function () {
        expect(wrapper.instance().calculatePages()).toEqual([]);
      });
    });
  });

  describe('calculatePageStatus', function () {
    var instance = void 0;
    var pageStatus = void 0;

    describe('default case', function () {
      var props = createMockProps();
      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
        instance = wrapper.instance();
        pageStatus = instance.calculatePageStatus(instance.calculatePages());
      });

      it('should returning correct format for page status', function () {
        pageStatus.forEach(function (p) {
          expect(Object.prototype.hasOwnProperty.call(p, 'page')).toBeTruthy();
          expect(Object.prototype.hasOwnProperty.call(p, 'active')).toBeTruthy();
          expect(Object.prototype.hasOwnProperty.call(p, 'disabled')).toBeTruthy();
          expect(Object.prototype.hasOwnProperty.call(p, 'title')).toBeTruthy();
        });
      });

      it('should mark active status as true when it is props.currPage', function () {
        expect(pageStatus.find(function (p) {
          return p.page === props.currPage;
        }).active).toBeTruthy();
      });

      it('only have one page\'s active status is true', function () {
        expect(pageStatus.filter(function (p) {
          return p.page === props.currPage;
        }).length).toEqual(1);
      });
    });

    describe('when alwaysShowAllBtns is false', function () {
      var props = createMockProps();
      describe('and props.currPage is on first page', function () {
        it('should filter out previous page indication', function () {
          var mockElement = _react2.default.createElement(MockComponent, props, null);
          wrapper = (0, _enzyme.shallow)(mockElement);
          instance = wrapper.instance();
          var pageList = instance.calculatePages();
          pageStatus = instance.calculatePageStatus(pageList);

          expect(pageStatus.find(function (p) {
            return p.page === props.prePageText;
          })).not.toBeDefined();
        });
      });

      describe('and props.currPage is on last page', function () {
        it('should filter out next page indication', function () {
          props.currPage = 10;
          var mockElement = _react2.default.createElement(MockComponent, props, null);
          wrapper = (0, _enzyme.shallow)(mockElement);
          instance = wrapper.instance();
          var pageList = instance.calculatePages();
          pageStatus = instance.calculatePageStatus(pageList);

          expect(pageStatus.find(function (p) {
            return p.page === props.nextPageText;
          })).not.toBeDefined();
        });
      });
    });
  });

  describe('calculateSizePerPageStatus', function () {
    describe('when props.sizePerPageList is an number array', function () {
      var props = createMockProps();
      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting correctly sizePerPage status', function () {
        var instance = wrapper.instance();
        var result = instance.calculateSizePerPageStatus();
        expect(result.length).toEqual(props.sizePerPageList.length);
        result.forEach(function (sizePerPage, i) {
          expect(sizePerPage.text).toEqual('' + props.sizePerPageList[i]);
          expect(sizePerPage.page).toEqual(props.sizePerPageList[i]);
        });
      });
    });

    describe('when props.sizePerPageList is an object array', function () {
      var props = createMockProps();
      props.sizePerPageList = [{
        text: 'ten', value: 10
      }, {
        text: 'thirty', value: 30
      }];

      beforeEach(function () {
        var mockElement = _react2.default.createElement(MockComponent, props, null);
        wrapper = (0, _enzyme.shallow)(mockElement);
      });

      it('should getting correctly sizePerPage status', function () {
        var instance = wrapper.instance();
        var result = instance.calculateSizePerPageStatus();
        expect(result.length).toEqual(props.sizePerPageList.length);
        result.forEach(function (sizePerPage, i) {
          expect(sizePerPage.text).toEqual(props.sizePerPageList[i].text);
          expect(sizePerPage.page).toEqual(props.sizePerPageList[i].value);
        });
      });
    });
  });
});